@@ -40,9 +40,8 @@ pub fn to_lyric(json: String) -> NCMResult<String> {
             .as_str()
             .ok_or(Errors::None)?
             .to_owned();
-        let buf = base64::decode(lyric).unwrap();
-        let lyric = String::from_utf8(buf).expect("utf8 error");
-        return Ok(lyric);
+        return String::from_utf8(base64::decode(lyric).map_err(|_| Errors::None)?)
+            .map_err(|_| Errors::None);
     }
     Err(Errors::None)
 }
