@@ -32,6 +32,25 @@ use unicode_truncate::{Alignment, UnicodeTruncateStr};
 impl MainActivity {
     pub fn sync_youtube_options(&mut self, page_index: u32) {
         if self.youtube_options.is_empty() {
+            if let Some(props) = self.view.get_props(super::COMPONENT_SCROLLTABLE_YOUTUBE) {
+                if let Some(domain) = &self.invidious_instance.domain {
+                    let props = table::TablePropsBuilder::from(props)
+                        .with_table(
+                            TableBuilder::default()
+                                .add_col(TextSpan::from(format!(
+                                    "Empty result.Probably {} is down.",
+                                    domain
+                                )))
+                                .build(),
+                        )
+                        .build();
+                    let msg = self
+                        .view
+                        .update(super::COMPONENT_SCROLLTABLE_YOUTUBE, props);
+                    self.update(msg);
+                }
+            }
+
             return;
         }
         let mut table: TableBuilder = TableBuilder::default();
@@ -53,12 +72,11 @@ impl MainActivity {
         }
         let table = table.build();
 
-        match self.view.get_props(super::COMPONENT_SCROLLTABLE_YOUTUBE) {
-            None => None,
-            Some(props) => {
+        if let Some(props) = self.view.get_props(super::COMPONENT_SCROLLTABLE_YOUTUBE) {
+            if let Some(domain) = &self.invidious_instance.domain {
                 let title = format!(
-                    "── Page {} ──┼── {} ────────────",
-                    page_index, "Tab/Shift+Tab for next and previous page"
+                    "── Page {} ──┼─ {} ─┼─ {} ─────",
+                    page_index, "Tab/Shift+Tab switch pages", domain,
                 );
                 let props = table::TablePropsBuilder::from(props)
                     .with_title(title, tuirealm::tui::layout::Alignment::Left)
@@ -67,8 +85,8 @@ impl MainActivity {
                     .with_table(table)
                     .build();
                 self.view
-                    .update(super::COMPONENT_SCROLLTABLE_YOUTUBE, props)
+                    .update(super::COMPONENT_SCROLLTABLE_YOUTUBE, props);
             }
-        };
+        }
     }
 }
