@@ -69,11 +69,9 @@ impl Context {
     }
 
     pub fn clear_image(&mut self) {
-        write!(self.context.backend_mut(), "\x1b_Ga=d\x1b\\").expect("error delete image");
-        self.context
-            .backend_mut()
-            .flush()
-            .expect("error flush delete image");
+        if write!(self.context.backend_mut(), "\x1b_Ga=d\x1b\\").is_ok()
+            && self.context.backend_mut().flush().is_ok()
+        {}
     }
 }
 
